# How to contribute

Hello there. Looks like you are interested in contributing to [PWSpy](https://github.com/nanthony21/PWSpy), which is just great, so welcome!
  
We are open to any kind of contribution: code, documentation, bug-fixing (even just reports), feature-requests and anything else you may come up with.

## Getting started

### Discussion
Please open an issue on the GitHub page for any discussion.

## Contributing

### Coding

Nothing fancy here, just:

1. Fork this repo
1. Commit you code
1. Submit a pull request. It will be reviewed by maintainers and they'll give you proper feedback so you can iterate over it.

#### Considerations
- Make sure existing tests pass
- Make sure your new code is properly tested and fully-covered
- Following [The seven rules of a great Git commit message](https://chris.beams.io/posts/git-commit/#seven-rules) is highly encouraged


### Testing

As mentioned above, existing tests must pass and new features are required to be tested and fully-covered.

### Documenting

Code should be self-documented. But, in case there is any code that may be hard to understand, it must include some comments to make it easier to review and maintain later on.
